##  Description
The organization fact sheet type is an essential element to represent your organization’s business architecture in SAP LeanIX; it should be used from the beginning as it allows you to get some basic views to understand synergies and gaps in the application landscape across different parts of the organization.
Overview of all relations to/from organization:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274856047a441014a41287c8eaa2a097_LowRes.png)
